import { Fragment, useEffect, useState } from 'react';
import Autocomplete from '@mui/material/Autocomplete';
import { TextField, Chip } from '@mui/material';

type TagsInputProps = {
  value: string[];
  onChange: (value: string[]) => void;
  placeholder?: string;
  label?: any;
  showLabel?: boolean;
  options?: string[];
};
export const TagsInput = ({ value, onChange, placeholder = '', label = '', showLabel = false, options = [] }: TagsInputProps) => {
  const [tags, setTags] = useState<string[]>(value);
  useEffect(() => {
    setTags(value);
  }, [value]);
  const randomid = () => {
    return Math.random().toString(36).substring(2, 15) + Math.random().toString(36).substring(2, 15);
  };
  return (
    <Autocomplete
      multiple
      freeSolo
      options={options || []}
      value={tags}
      onChange={(event, newValue) => {
        // setTags(newValue as string[]);
        onChange(newValue as string[]);
      }}
      sx={{
        width: '100%',
      }}
      renderTags={(value: string[], getTagProps) => {
        const id = randomid();
        const com = value.map((option: string, index: number) => (
          <Chip
            variant='outlined'
            sx={{
              borderColor: 'primary.main',
              borderRadius: '4px',
              '&:hover': {
                borderColor: 'primary.main',
              },
              '& .MuiChip-deleteIcon': {
                color: 'secondary.main',
              },
            }}
            label={option}
            {...getTagProps({ index })}
            key={`${id}-${index}`}
          />
        ));
        return <Fragment key={id}>{com}</Fragment>;
      }}
      renderInput={(params) => <TextField {...params} label={showLabel ? label : ''} placeholder={placeholder} />}
    />
  );
};
